@@ -20,7 +20,9 @@ Should never be called; subclasses should override.
 
 =cut
 
-sub new { croak "Scheduler should not be instantiated directly: use a subclass."; }
+sub new {
+    croak "Scheduler should not be instantiated directly: use a subclass.";
+}
 
 =head2 get_next_unique
 
@@ -30,7 +32,9 @@ returned more than once between calls to reset_available.
 
 =cut
 
-sub get_next_unique { croak "get_next_unique must be overridden."; }
+sub get_next_unique {
+    croak "get_next_unique must be overridden.";
+}
 
 =head2 next_available
 
@@ -45,23 +49,31 @@ whether it is worth waiting for more results.
 
 =cut
 
-sub next_available { croak "next_available must be overridden."; }
+sub next_available {
+    croak "next_available must be overridden.";
+}
 
 =head2 reset_available
 
-This is called in order to indicate that all items should once more be made available.
+This is called in order to indicate that all items should once more be made
+available.
 
 =cut
 
-sub reset_available { croak "reset_available must be overridden."; }
+sub reset_available {
+    croak "reset_available must be overridden.";
+}
 
 =head2 process_feedback
 
-This is called to provide information about the performance of a geocoder. Does nothing by default.
+This is called to provide information about the performance of a geocoder. Does
+nothing by default.
 
 =cut
 
-sub process_feedback { return; }
+sub process_feedback {
+    return;
+}
 
 1;
 
